@@ -1,5 +1,5 @@
 import struct
-from enum import IntEnum
+from enum import IntEnum, IntFlag
 
 from spherov2.commands import Commands
 from spherov2.helper import to_bytes, to_int
@@ -8,6 +8,38 @@ from spherov2.listeners.sensor import SensorStreamingMask, CollisionDetected, Bo
     MotorThermalProtectionStatus, ThermalProtectionStatus
 
 
+class CliffDetectionSensorLocations(IntFlag):
+    FRONT_LEFT = 0x1  # 0b1
+    FRONT_RIGHT = 0x2  # 0b10
+    BACK_LEFT = 0x4  # 0b100
+    BACK_RIGHT = 0x8  # 0b1000
+
+
+class CollisionDetectedAxis(IntFlag):
+    X_AXIS = 0x1  # 0b1
+    Y_AXIS = 0x2  # 0b10
+
+
+class GyroMaxFlags(IntFlag):
+    MAX_PLUS_X = 0x1  # 0b1
+    MAX_MINUS_X = 0x2  # 0b10
+    MAX_PLUS_Y = 0x4  # 0b100
+    MAX_MINUS_Y = 0x8  # 0b1000
+    MAX_PLUS_Z = 0x10  # 0b10000
+    MAX_MINUS_Z = 0x20  # 0b100000
+
+
+class InfraredSensorLocations(IntFlag):
+    FRONT_LEFT = 0xff  # 0b11111111
+    FRONT_RIGHT = 0xff00  # 0b1111111100000000
+    BACK_LEFT = 0xff000000  # 0b11111111000000000000000000000000 #How it's displayed in decompiled: -0x1000000
+    BACK_RIGHT = 0xff0000  # 0b111111110000000000000000
+
+
+class LocatorFlags(IntFlag):
+    AUTO_CALIBRATE = 0x1  # 0b1
+
+
 class CollisionDetectionMethods(IntEnum):
     NO_COLLISION_DETECTION = 0
     ACCELEROMETER_BASED_DETECTION = 1
@@ -15,6 +47,11 @@ class CollisionDetectionMethods(IntEnum):
     HYBRID_ACCELEROMETER_AND_CONTROL_SYSTEM_DETECTION = 3
 
 
+class MotorIndexes(IntEnum):
+    LEFT_MOTOR_INDEX = 0
+    RIGHT_MOTOR_INDEX = 1
+
+
 class SensitivityBasedCollisionDetectionMethods(IntEnum):
     ACCELEROMETER_BASED_DETECTION = 0
 
@@ -28,6 +65,18 @@ class SensitivityLevels(IntEnum):
     VERY_LOW = 5
 
 
+class SteamingDataSizes(IntEnum):
+    EIGHT_BIT = 0
+    SIXTEEN_BIT = 1
+    THIRTY_TWO_BIT = 2
+
+
+class ThermalProtectionStatus(IntEnum):
+    OK = 0
+    WARN = 1
+    CRITICAL = 2
+
+
 class Sensor(Commands):
     _did = 24
 
@@ -76,6 +125,10 @@ class Sensor(Commands):
     def reset_locator_x_and_y(toy, proc=None):
         toy._execute(Sensor._encode(toy, 19, proc))
 
+    @staticmethod
+    def enable_collision_detected_notify(toy, enable: bool, proc=None):  # Untested
+        toy._execute(Sensor._encode(toy, 20, proc, [int(enable)]))
+
     @staticmethod
     def set_locator_flags(toy, locator_flags: bool, proc=None):
         toy._execute(Sensor._encode(toy, 23, proc, [int(locator_flags)]))
@@ -127,6 +180,14 @@ class Sensor(Commands):
     def stop_robot_to_robot_infrared_broadcasting(toy, proc=None):
         toy._execute(Sensor._encode(toy, 41, proc))
 
+    @staticmethod
+    def send_robot_to_robot_infrared_message(toy, s, s2, s3, s4, s5, proc=None):  # Untested / Unknown param names
+        toy._execute(Sensor._encode(toy, 42, proc, [s, s2, s3, s4, s5]))
+
+    @staticmethod
+    def listen_for_robot_to_robot_infrared_message(toy, s, j, proc=None):  # Untested / Unknown param names
+        toy._execute(Sensor._encode(toy, 43, proc, [s, j]))
+
     robot_to_robot_infrared_message_received_notify = (24, 44, 0xff), lambda listener, p: listener(p.data[0])
 
     @staticmethod
