@@ -174,6 +174,11 @@ class Packet(NamedTuple):
                     self.__callback(Packet.parse_response(pkt))
 
 
+class AnimationControl:
+    def __init__(self, toy):
+        self.__toy = toy
+
+
 class DriveControl:
     def __init__(self, toy):
         self.__toy = toy
@@ -218,6 +223,11 @@ class DriveControl:
         self.__toy.reset_yaw()
 
 
+class FirmwareUpdateControl:
+    def __init__(self, toy):
+        self.__toy = toy
+
+
 class LedControl:
     def __init__(self, toy):
         self.__toy = toy
@@ -319,6 +329,11 @@ class SensorControl:
         self.__update()
 
 
+class StatsControl:
+    def __init__(self, toy):
+        self.__toy = toy
+
+
 class Processors(IntEnum):
     UNKNOWN = 0
     PRIMARY = 1
