@@ -1,6 +1,6 @@
-from spherov2.toy import Toy
+from spherov2.toy.sphero import Sphero as SPHERO
 from spherov2.types import ToyType
 
 
-class Sprk2(Toy):
+class Sprk2(SPHERO):
     toy_type = ToyType('Sphero SPRK+', 'SK-', 'SK', .06)
