@@ -120,6 +120,15 @@ class ToyUtil:
                     toy.LEDs.BODY_GREEN: g,
                     toy.LEDs.BODY_BLUE: b
                 }
+            elif isinstance(toy, Mini):
+                mapping = {
+                    toy.LEDs.BODY_RED: r,
+                    toy.LEDs.BODY_GREEN: g,
+                    toy.LEDs.BODY_BLUE: b,
+                    toy.LEDs.USER_BODY_RED: r,
+                    toy.LEDs.USER_BODY_GREEN: g,
+                    toy.LEDs.USER_BODY_BLUE: b
+                }
             elif isinstance(toy, RVR):
                 mapping = {
                     toy.LEDs.RIGHT_HEADLIGHT_RED: r,
@@ -190,6 +199,12 @@ class ToyUtil:
                 toy.LEDs.FRONT_GREEN: g,
                 toy.LEDs.FRONT_BLUE: b
             }
+        elif isinstance(toy, Mini):
+            mapping = {
+                toy.LEDs.BODY_RED: r,
+                toy.LEDs.BODY_GREEN: g,
+                toy.LEDs.BODY_BLUE: b
+            }
         else:
             mapping = None
         ToyUtil.set_multiple_leds(toy, mapping, not_supported_handler)
@@ -211,6 +226,12 @@ class ToyUtil:
                 toy.LEDs.BACK_GREEN: g,
                 toy.LEDs.BACK_BLUE: b
             }
+        elif isinstance(toy, Mini):
+            mapping = {
+                toy.LEDs.USER_BODY_RED: r,
+                toy.LEDs.USER_BODY_GREEN: g,
+                toy.LEDs.USER_BODY_BLUE: b
+            }
         else:
             mapping = None
         ToyUtil.set_multiple_leds(toy, mapping, not_supported_handler)
@@ -321,6 +342,102 @@ class ToyUtil:
         elif not_supported_handler:
             not_supported_handler()
 
+    @staticmethod
+    def set_matrix_pixel(toy: Toy, x: int, y: int, r: int, g: int, b: int, is_user_color: bool,
+                         not_supported_handler: Callable[[], None] = None):
+        def _fallback():
+            not_supported_handler()
+
+        ToyUtil.set_led_matrix_pixel(toy, x, y, r, g, b, _fallback)
+
+    @staticmethod
+    def set_led_matrix_pixel(toy: Toy, x: int, y: int, r: int, g: int, b: int,
+                             not_supported_handler: Callable[[], None] = None):
+        if toy.implements(IO.set_compressed_frame_player_pixel):
+            toy.set_compressed_frame_player_pixel(x, y, r, g, b)
+        elif not_supported_handler:
+            not_supported_handler()
+
+    @staticmethod
+    def set_matrix_line(toy: Toy, x1: int, y1: int, x2: int, y2: int, r: int, g: int, b: int, is_user_color: bool,
+                        not_supported_handler: Callable[[], None] = None):
+        def _fallback():
+            not_supported_handler()
+
+        ToyUtil.set_led_matrix_line(toy, x1, y1, x2, y2, r, g, b, _fallback)
+
+    @staticmethod
+    def set_led_matrix_line(toy: Toy, x1: int, y1: int, x2: int, y2: int, r: int, g: int, b: int,
+                            not_supported_handler: Callable[[], None] = None):
+        if toy.implements(IO.draw_compressed_frame_player_line):
+            toy.draw_compressed_frame_player_line(x1, y1, x2, y2, r, g, b)
+        elif not_supported_handler:
+            not_supported_handler()
+
+    @staticmethod
+    def set_matrix_fill(toy: Toy, x1: int, y1: int, x2: int, y2: int, r: int, g: int, b: int, is_user_color: bool,
+                        not_supported_handler: Callable[[], None] = None):
+        def _fallback():
+            not_supported_handler()
+
+        ToyUtil.set_led_matrix_fill(toy, x1, y1, x2, y2, r, g, b, _fallback)
+
+    @staticmethod
+    def set_led_matrix_fill(toy: Toy, x1: int, y1: int, x2: int, y2: int, r: int, g: int, b: int,
+                            not_supported_handler: Callable[[], None] = None):
+        if toy.implements(IO.draw_compressed_frame_player_fill):
+            toy.draw_compressed_frame_player_fill(x1, y1, x2, y2, r, g, b)
+        elif not_supported_handler:
+            not_supported_handler()
+
+    @staticmethod
+    def set_matrix_pixel(toy: Toy, x: int, y: int, r: int, g: int, b: int, is_user_color: bool,
+                         not_supported_handler: Callable[[], None] = None):
+        def _fallback():
+            not_supported_handler()
+
+        ToyUtil.set_led_matrix_pixel(toy, x, y, r, g, b, _fallback)
+
+    @staticmethod
+    def set_led_matrix_pixel(toy: Toy, x: int, y: int, r: int, g: int, b: int,
+                             not_supported_handler: Callable[[], None] = None):
+        if toy.implements(IO.set_compressed_frame_player_pixel):
+            toy.set_compressed_frame_player_pixel(x, y, r, g, b)
+        elif not_supported_handler:
+            not_supported_handler()
+
+    @staticmethod
+    def set_matrix_line(toy: Toy, x1: int, y1: int, x2: int, y2: int, r: int, g: int, b: int, is_user_color: bool,
+                        not_supported_handler: Callable[[], None] = None):
+        def _fallback():
+            not_supported_handler()
+
+        ToyUtil.set_led_matrix_line(toy, x1, y1, x2, y2, r, g, b, _fallback)
+
+    @staticmethod
+    def set_led_matrix_line(toy: Toy, x1: int, y1: int, x2: int, y2: int, r: int, g: int, b: int,
+                            not_supported_handler: Callable[[], None] = None):
+        if toy.implements(IO.draw_compressed_frame_player_line):
+            toy.draw_compressed_frame_player_line(x1, y1, x2, y2, r, g, b)
+        elif not_supported_handler:
+            not_supported_handler()
+
+    @staticmethod
+    def set_matrix_fill(toy: Toy, x1: int, y1: int, x2: int, y2: int, r: int, g: int, b: int, is_user_color: bool,
+                        not_supported_handler: Callable[[], None] = None):
+        def _fallback():
+            not_supported_handler()
+
+        ToyUtil.set_led_matrix_fill(toy, x1, y1, x2, y2, r, g, b, _fallback)
+
+    @staticmethod
+    def set_led_matrix_fill(toy: Toy, x1: int, y1: int, x2: int, y2: int, r: int, g: int, b: int,
+                            not_supported_handler: Callable[[], None] = None):
+        if toy.implements(IO.draw_compressed_frame_player_fill):
+            toy.draw_compressed_frame_player_fill(x1, y1, x2, y2, r, g, b)
+        elif not_supported_handler:
+            not_supported_handler()
+
     @staticmethod
     def turn_off_leds(toy: Toy):
         if hasattr(toy, 'LEDs'):
@@ -331,9 +448,6 @@ class ToyUtil:
         if isinstance(toy, RVR):
             mapping.pop(RVR.LEDs.UNDERCARRIAGE_WHITE)
 
-        # elif isinstance(toy, Mini): TODO
-        #     mapping.pop
-
         def __fallback():
             ToyUtil.set_main_led(toy, 0, 0, 0, False)
             ToyUtil.set_back_led_brightness(toy, 0)
@@ -341,6 +455,34 @@ class ToyUtil:
         ToyUtil.set_multiple_leds(toy, mapping, __fallback)
         ToyUtil.set_led_matrix_one_colour(toy, 0, 0, 0)
 
+    # Bolt Animation
+    def register_matrix_animation(toy: Toy, s, s2, z, s3, s_arr, i, i_arr,
+                                  not_supported_handler: Callable[[], None] = None):
+        def _fallback():
+            not_supported_handler()
+
+        ToyUtil.save_compressed_frame_player_animation(toy, s, s2, z, s3, s_arr, i, i_arr, _fallback)
+
+    def save_compressed_frame_player_animation(toy: Toy, s, s2, z, s3, s_arr, i, i_arr,
+                                               not_supported_handler: Callable[[], None] = None):
+        if toy.implements(IO.save_compressed_frame_player_animation):
+            toy.save_compressed_frame_player_animation(s, s2, z, s3, s_arr, i, i_arr)
+        elif not_supported_handler:
+            not_supported_handler()
+
+    def play_matrix_animation(toy: Toy, s, not_supported_handler: Callable[[], None] = None):
+        def _fallback():
+            not_supported_handler()
+
+        ToyUtil.save_compressed_frame_player_animation(toy, s, s2, z, s3, s_arr, i, i_arr, _fallback)
+
+    def play_compressed_frame_player_animation(toy: Toy, s, not_supported_handler: Callable[[], None] = None):
+        if toy.implements(IO.play_compressed_frame_player_animation):
+            toy.play_compressed_frame_player_animation(s)
+        elif not_supported_handler:
+            not_supported_handler()
+
+    # Sound
     @staticmethod
     def play_sound(toy: Toy, sound: IntEnum, force_play: bool, not_supported_handler: Callable[[], None] = None):
         if toy.implements(IO.play_audio_file):
